@@ -15,7 +15,7 @@ Readonly::Scalar my $EMPTY_STR => q{};
 Readonly::Scalar my $SPACE => q{ };
 
 # Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Attributes.
 sub _put_attribute {
@@ -254,9 +254,21 @@ L<Tags::Utils>.
 
 =head1 SEE ALSO
 
-L<Tags>,
-L<Tags::Output>,
-L<Tags::Output::Raw>.
+=over
+
+=item L<Tags>
+
+Structure oriented SGML/XML/HTML/etc. elements manipulation.
+
+=item L<Task::PYX>
+
+Install the PYX modules.
+
+=item L<Task::Tags>
+
+Install the Tags modules.
+
+=back
 
 =head1 AUTHOR
 
@@ -269,6 +281,6 @@ Michal Špaček L<skim@cpan.org>
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
